@@ -48,7 +48,7 @@ list_loci_in_c_region_fasta_dir <- function(fasta_dir, loci_prefix)
         stop(wmsg("'fasta_dir' must be a single (non-empty) string"))
     if (!dir.exists(fasta_dir))
         stop(wmsg("directory ", fasta_dir, " not found"))
-    stop_if_bad_loci(loci)
+    stop_if_malformed_loci_vector(loci)
     wanted_files <- file.path(fasta_dir, paste0(loci, "C.fasta"))
     stopifnot(all(file.exists(wanted_files)))
     wanted_files
@@ -91,7 +91,7 @@ create_c_region_db <- function(fasta_dir, loci, destdir, force=FALSE)
     ## avoids loosing the content of the existing 'destdir' in case something
     ## goes wrong.
     tmp_destdir <- tempfile("c_region_db_")
-    dir.create(tmp_destdir, recursive=TRUE)
+    dir.create(tmp_destdir)
     on.exit(nuke_file(tmp_destdir))
     create_region_db(fasta_files, tmp_destdir, region_type="C")
     rename_file(tmp_destdir, destdir, replace=TRUE)
